unit-test-docker: ubuntu:bionic -> ubuntu:disco

This updates us to the soon to be released version of ubuntu, skipping
cosmic so that we don't have to jump verisons again for a while. The
main draw here is to get a newer version of systemd to match the version
we are using in yocto (237 -> 240). This also gives us the benefit of
being able to clean up the gcc override for gcc-8 since it is the
default in disco.

Change-Id: I2327b481bdbe6b8a1c82d193bdc8d9b5e1a6e452
Signed-off-by: William A. Kennington III <wak@google.com>
diff --git a/build-unit-test-docker.sh b/build-unit-test-docker.sh
index 8d3b4e3..0d92880 100755
--- a/build-unit-test-docker.sh
+++ b/build-unit-test-docker.sh
@@ -6,7 +6,7 @@
 #   DOCKER_IMG_NAME:  <optional, the name of the docker image to generate>
 #                     default is openbmc/ubuntu-unit-test
 #   DISTRO:           <optional, the distro to build a docker image against>
 #                     default is ubuntu:bionic
 #   BRANCH:           <optional, branch to build from each of the openbmc/
 #                     respositories>
 #                     default is master, which will be used if input branch not
@@ -15,7 +15,7 @@
 set -uo pipefail
 
 DOCKER_IMG_NAME=${DOCKER_IMG_NAME:-"openbmc/ubuntu-unit-test"}
-DISTRO=${DISTRO:-"ubuntu:bionic"}
+DISTRO=${DISTRO:-"ubuntu:disco"}
 BRANCH=${BRANCH:-"master"}
 
 # Determine the architecture
@@ -155,8 +155,8 @@
 RUN cat /etc/apt/sources.list.d/debug.list
 
 RUN apt-get update && apt-get install -yy \
-    gcc-8 \
-    g++-8 \
+    gcc \
+    g++ \
     libc6-dbg \
     libc6-dev \
     libtool \
@@ -210,13 +210,6 @@
     libprotobuf-dev \
     protobuf-compiler
 
-# Make gcc8 and g++8 the default
-RUN update-alternatives --install /usr/bin/gcc gcc /usr/bin/gcc-8 800 \
-  --slave /usr/bin/g++ g++ /usr/bin/g++-8 \
-  --slave /usr/bin/gcov gcov /usr/bin/gcov-8 \
-  --slave /usr/bin/gcov-dump gcov-dump /usr/bin/gcov-dump-8 \
-  --slave /usr/bin/gcov-tool gcov-tool /usr/bin/gcov-tool-8
-
 RUN pip install inflection
 RUN pip install pycodestyle
 RUN pip3 install meson==0.49.0
@@ -6,7 +6,7 @@
 #                     default is openbmc/ubuntu-unit-test
 #   DISTRO:           <optional, the distro to build a docker image against>
-#                     default is ubuntu:bionic
+#                     default is ubuntu:disco
 #   BRANCH:           <optional, branch to build from each of the openbmc/
 #                     respositories>